#ifndef CONFIG_H
#define CONFIG_H

/****************************************************************

    Copyright (c) 1996-1997 Fred Pesch

    This program is free software; you can redistribute it 
    and/or modify it under the terms of the GNU General 
    Public License as published by the Free Software 
    Foundation (version 2 of the License).

    This program is distributed in the hope that it will 
    be useful, but WITHOUT ANY WARRANTY; without even the 
    implied warranty of MERCHANTABILITY or FITNESS FOR A 
    PARTICULAR PURPOSE.  See the GNU General Public License 
    for more details.

    For a copy of the GNU General Public License, write to the 
    Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
    MA 02139, USA.

****************************************************************/

#include <Xm/XmAll.h>

/* File Format structure */

typedef struct {
  char *description;
  char *pattern;
  char *view_command;
  char *edit_command;
  char *pixmap_name;
  Pixmap pixmap;
} TFormatList;

/* Variable structure */

typedef struct {
  char *name;
  int int_val;
  Bool bool_val;
  char *str_val;
} TVarList;

/* User Menu structure */

typedef enum { POPUP, MENUITEM, SEPARATOR } TMenuType;

typedef struct {
  TMenuType type;
  char *name;
  char *command;
} TMenuEntry;

typedef struct {
  char *ident;
  char *name;
  int nb_entries;
  TMenuEntry *entry;
} TPopupList;

/* global vars */

extern TFormatList* G_FormatList;
extern int G_NbFormats;
extern TVarList* G_VarList;
extern int G_NbVars;
extern TPopupList *G_MenuList;
extern int G_NbMenus;
extern TPopupList *G_CMenuList;
extern int G_NbCMenus;
extern char **G_PixmapPath;
extern int G_NbPaths;
  

/*--------------------------------------------------------------------------*/
/* user menu functions   */
/*-----------------------*/

extern void AddMenu(char *ident, char *name);
extern void AddMenuItem(char *name, char *command);
extern void AddMenuSeparator(void);
extern void AddMenuPopup(char *ident);
extern void DestroyPopupList(void);

/*--------------------------------------------------------------------------*/
/* context menus functions   */
/*---------------------------*/

extern void AddCMenu(char *ident, char *name);
extern void AddCMenuItem(char *name, char *command);
extern void AddCMenuSeparator(void);
extern void DestroyCMenuList(void);

/*--------------------------------------------------------------------------*/
/* file format functions */
/*-----------------------*/

extern void AddFileFormat(char *desc, char *pattern, char *view, char *edit, char *pixmap);
extern void DestroyFormatList(void);
extern Pixmap GetFormatPixmap(char *filename);
extern int GetFormatPriority(char *filename);
extern char *GetFormatViewCommand(char *filename);
extern char *GetFormatEditCommand(char *filename);
extern char *GetFormatDescription(char *filename);

/*--------------------------------------------------------------------------*/
/* var list functions    */
/*-----------------------*/

extern void AddVarList(char *name, int int_val, Bool bool_val, char *str_val);
extern void AddPredefinedVar(char *name, int int_val, Bool bool_val, char *str_val);
extern void DestroyVarList(void);
extern int GetVarInt(char *name, int *result);
extern int GetVarBool(char *name, Bool *result);
extern int GetVarString(char *name, char **result);

extern void LoadConfigFile(char *rcfile);

#endif



