#define DIRHISTORY_H

/****************************************************************

    Copyright (c) 1996-1997 Fred Pesch

    This program is free software; you can redistribute it 
    and/or modify it under the terms of the GNU General 
    Public License as published by the Free Software 
    Foundation (version 2 of the License).

    This program is distributed in the hope that it will 
    be useful, but WITHOUT ANY WARRANTY; without even the 
    implied warranty of MERCHANTABILITY or FITNESS FOR A 
    PARTICULAR PURPOSE.  See the GNU General Public License 
    for more details.

    For a copy of the GNU General Public License, write to the 
    Free Software Foundation, Inc., 675 Mass Ave, Cambridge, 
    MA 02139, USA.

****************************************************************/

#include "config.h"
#include "interface.h"

typedef struct {
  char **DirNames;
  int NbDirs;
  int MaxDirs;
} TDirHistory;

TDirHistory DirHistory;

void InitDirHistory(void)
{
  if(!GetVarInt("MaxHistoryDirs", &DirHistory.MaxDirs))
    DirHistory.MaxDirs=16;

  DirHistory.DirNames = (char **) XtMalloc(sizeof(char *)*DirHistory.MaxDirs);
  DirHistory.NbDirs=0;
}

void DeleteDirHistory(void)
{
  int i;

  for(i=0;i<DirHistory.NbDirs;i++)
    XtFree(DirHistory.DirNames[i]);

  XtFree( (char *) DirHistory.DirNames);

  DirHistory.NbDirs=0;
  
}


void UpdateHistoryComboBoxes(void)
{
  Widget w_temp,w_cbox;
  XmString xmsdir;
  int i;

  /* Copy combobox */

  w_cbox = XtNameToWidget(W_MainWindow, "*CopyDirSelectorText");
  if(w_cbox!=NULL) {
    w_temp = XtNameToWidget(w_cbox, "*List");
 
    XmListDeleteAllItems(w_temp);

    for(i=0;i<DirHistory.NbDirs;i++) {
      xmsdir=XmStringCreateSimple(DirHistory.DirNames[i]);
      XmListAddItem(w_temp, xmsdir, 1);
      XmStringFree(xmsdir);
    }

    XtVaSetValues(w_temp, XmNvisibleItemCount, DirHistory.NbDirs, NULL);
    XmComboBoxUpdate(w_cbox);

  }

  /* Move combobox */

  w_cbox = XtNameToWidget(W_MainWindow, "*MoveDirSelectorText");
  if(w_cbox!=NULL) {
    w_temp = XtNameToWidget(w_cbox, "*List");
 
    XmListDeleteAllItems(w_temp);

    for(i=0;i<DirHistory.NbDirs;i++) {
      xmsdir=XmStringCreateSimple(DirHistory.DirNames[i]);
      XmListAddItem(w_temp, xmsdir, 1);
      XmStringFree(xmsdir);
    }

    XtVaSetValues(w_temp, XmNvisibleItemCount, DirHistory.NbDirs, NULL);
    XmComboBoxUpdate(w_cbox);

  }

  /* GotoDir combobox */

  w_cbox = XtNameToWidget(W_MainWindow, "*GoToDirSelectorText");
  if(w_cbox!=NULL) {
    w_temp = XtNameToWidget(w_cbox, "*List");
 
    XmListDeleteAllItems(w_temp);

    for(i=0;i<DirHistory.NbDirs;i++) {
      xmsdir=XmStringCreateSimple(DirHistory.DirNames[i]);
      XmListAddItem(w_temp, xmsdir, 1);
      XmStringFree(xmsdir);
    }

    XtVaSetValues(w_temp, XmNvisibleItemCount, DirHistory.NbDirs, NULL);
    XmComboBoxUpdate(w_cbox);

  }


}
    
void AddDirInHistory(char *dir)
{
  int i;
  int found;

  /* search if the dir is in the list */

  found=0;
  for(i=0;i<DirHistory.NbDirs;i++)
    if(strcmp(DirHistory.DirNames[i],dir)==0) found=1;

  /* yes ? don't add it */

  if(found) return;

  /* if the history stack is full, remove the oldest dir */

  if(DirHistory.NbDirs==DirHistory.MaxDirs) {
    XtFree(DirHistory.DirNames[0]);
    for(i=0;i<DirHistory.NbDirs-1;i++) 
      DirHistory.DirNames[i]=DirHistory.DirNames[i+1];
    DirHistory.DirNames[DirHistory.NbDirs-1] = XtMalloc(strlen(dir)+1);
    strcpy(DirHistory.DirNames[DirHistory.NbDirs-1], dir);
  }
  else {

    /* else, add it on the top */

    DirHistory.NbDirs++;
    DirHistory.DirNames[DirHistory.NbDirs-1] = XtMalloc(strlen(dir)+1);
    strcpy(DirHistory.DirNames[DirHistory.NbDirs-1], dir);
  }

  UpdateHistoryComboBoxes();

}
  



